@@ -1,11 +1,11 @@
 /*
  *  backup.c
- * 
+ *
  *  Copyright (c) 2005 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2005 by Christian Hamar <krics@linuxforum.hu>
  *  Copyright (c) 2006 by Miklos Vajna <vmiklos@frugalware.org>
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -17,9 +17,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -33,12 +31,53 @@
 #include "log.h"
 #include "util.h"
 
-/* Look for a filename in a pmpkg_t.backup list.  If we find it,
- * then we return the md5 or sha1 hash (parsed from the same line)
- */
-char *_alpm_needbackup(const char *file, alpm_list_t *backup)
+/* split a backup string "file\thash" into two strings : file and hash */
+int _alpm_backup_split(const char *string, char **file, char **hash)
 {
-	alpm_list_t *lp;
+	char *str = strdup(string);
+	char *ptr;
+
+	/* tab delimiter */
+	ptr = strchr(str, '\t');
+	if(ptr == NULL) {
+		if(file) {
+			*file = str;
+		}
+		return(0);
+	}
+	*ptr = '\0';
+	ptr++;
+	/* now str points to the filename and ptr points to the hash */
+	if(file) {
+		*file = strdup(str);
+	}
+	if(hash) {
+		*hash = strdup(ptr);
+	}
+	FREE(str);
+	return(1);
+}
+
+char *_alpm_backup_file(const char *string)
+{
+	char *file = NULL;
+	_alpm_backup_split(string, &file, NULL);
+	return(file);
+}
+
+char *_alpm_backup_hash(const char *string)
+{
+	char *hash = NULL;
+	_alpm_backup_split(string, NULL, &hash);
+	return(hash);
+}
+
+/* Look for a filename in a pmpkg_t.backup list.  If we find it,
+ * then we return the md5 hash (parsed from the same line)
+ */
+char *_alpm_needbackup(const char *file, const alpm_list_t *backup)
+{
+	const alpm_list_t *lp;
 
 	ALPM_LOG_FUNC;
 
@@ -46,26 +85,22 @@ char *_alpm_needbackup(const char *file, alpm_list_t *backup)
 		return(NULL);
 	}
 
-	/* run through the backup list and parse out the md5 or sha1 hash for our file */
+	/* run through the backup list and parse out the hash for our file */
 	for(lp = backup; lp; lp = lp->next) {
-		char *str = strdup(lp->data);
-		char *ptr;
-		
-		/* tab delimiter */
-		ptr = strchr(str, '\t');
-		if(ptr == NULL) {
-			FREE(str);
+		char *filename = NULL;
+		char *hash = NULL;
+
+		/* no hash found */
+		if(!_alpm_backup_split((char *)lp->data, &filename, &hash)) {
+			FREE(filename);
 			continue;
 		}
-		*ptr = '\0';
-		ptr++;
-		/* now str points to the filename and ptr points to the md5 or sha1 hash */
-		if(strcmp(file, str) == 0) {
-			char *hash = strdup(ptr);
-			FREE(str);
+		if(strcmp(file, filename) == 0) {
+			FREE(filename);
 			return(hash);
 		}
-		FREE(str);
+		FREE(filename);
+		FREE(hash);
 	}
 
 	return(NULL);
