@@ -1,8 +1,8 @@
 /*
  *  backup.h
- * 
- *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
- * 
+ *
+ *  Copyright (c) 2002-2007 by Judd Vinet <jvinet@zeroflux.org>
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -14,16 +14,16 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _ALPM_BACKUP_H
 #define _ALPM_BACKUP_H
 
 #include "alpm_list.h"
 
-char *_alpm_needbackup(const char *file, alpm_list_t *backup);
+char *_alpm_backup_file(const char *string);
+char *_alpm_backup_hash(const char *string);
+char *_alpm_needbackup(const char *file, const alpm_list_t *backup);
 
 #endif /* _ALPM_BACKUP_H */
 
